Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(55)

Unified Diff: webrtc/base/thread.cc

Issue 2135173002: Revert of Protect MessageQueue stop field with a critical section to avoid data races. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/base/messagequeue.cc ('k') | webrtc/build/sanitizers/tsan_suppressions_webrtc.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/base/thread.cc
diff --git a/webrtc/base/thread.cc b/webrtc/base/thread.cc
index af5e68bedf81234704fa3d8e611d196f13865b90..5278c9321eae369167fb5717d5be84c6caa16021 100644
--- a/webrtc/base/thread.cc
+++ b/webrtc/base/thread.cc
@@ -218,7 +218,7 @@
ASSERT(!running());
if (running()) return false;
- Restart(); // reset IsQuitting() if the thread is being restarted
+ Restart(); // reset fStop_ if the thread is being restarted
// Make sure that ThreadManager is created on the main thread before
// we start a new thread.
@@ -346,7 +346,7 @@
MessageHandler* phandler,
uint32_t id,
MessageData* pdata) {
- if (IsQuitting())
+ if (fStop_)
return;
// Sent messages are sent to the MessageHandler directly, in the context
« no previous file with comments | « webrtc/base/messagequeue.cc ('k') | webrtc/build/sanitizers/tsan_suppressions_webrtc.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698